<template>
	<div class="e-chart-root">
		<div class="e-chart-container">
			<div class="e-chart" ref="chart"></div>
		</div>
	</div>
</template>

<script>
// 引入 ECharts 主模块
import ECharts from "echarts/lib/echarts";
//引入折线图
import "echarts/lib/chart/bar";
import "echarts/lib/chart/pictorialBar";

//引入提示框
import "echarts/lib/component/tooltip";
//引入标题
import "echarts/lib/component/title";
//引入图例标志
import "echarts/lib/component/legend";
//区域缩放
import "echarts/lib/component/dataZoom";

//markeline
import "echarts/lib/component/markLine";

// 引入自定义主题
import "./theme/transparent";

export default {
	chart: "",
	props: {
		barWidth: {
			type: Number,
			default: 24,
		},
		barColor: {
			type: String,
			default: "#90ed7d",
		},
		bgColor: {
			type: String,
			default: "#0b388a",
		},
		fontColor: {
			type: String,
			default: "#fff",
		},
		max: {
			type: Number,
			default: 400,
		},
	},
	data() {
		return {};
	},
	methods: {
		setOption(option) {
			let chart = this.$options.chart;
			if (chart) {
				chart.setOption(option);
			}
		},
		setData(data) {
			let option = this.getInitOption(data);
			let name = data.name;
			// 处理value=0时显示Bug,并对数值取绝对值
			let list = data.list.map((item) => item.value);
			let xName = data.list.map((item) => item.name);

			option.xAxis[0].data = xName;

			option.series[0].name = name;
			option.series[0].data = list;
			option.series[1].data = list;
			option.series[2].data = list;
			this.setOption(option);
		},
		getInitOption(opt) {
			let barWidth = this.barWidth;
			let barColor = this.barColor;
			let bgColor = this.bgColor;
			return {
				animation: false,
				title: this.getTitle(opt),
				tooltip: {},
				grid: {
					left: '1%',
					right: '1%',
					bottom: '2%',
					containLabel: true,
				},
				xAxis: [
					{
						type: "category",
						axisLine: {
							show: true,
							lineStyle: {
								color: '#b3b3b3',
							}
						},
						axisLabel: {
							color: '#737474',
							textStyle: {
								fontSize: 10
							},
						},
						data: [],
					},
				],
				yAxis: [
					{
						type: "value",
						gridIndex: 0,
						axisLine: {
							show: true,
							lineStyle: {
								color: '#b3b3b3',
							}
						},
						axisLabel: {
							color: '#737474',
							textStyle: {
								fontSize: 10
							},
						},
					},
				],
				series: [
					{
						name: "",
						type: "bar",
						barWidth: barWidth,
						itemStyle: {
							normal: {
								color: barColor,
							},
						},
						data: [],
						z: 10,
						zlevel: 0,
					},
					{
						// 背景
						type: "pictorialBar",
						animationDuration: 0,
						symbolRepeat: "fixed",
						symbolMargin: "20%",
						symbol: "roundRect",
						symbolSize: [barWidth, 6],
						itemStyle: {
							normal: {
								color: bgColor,
							},
						},
						label: {
							normal: {
								show: false,
							},
						},
						data: [],
						z: 0,
					},
					{
						// 分隔
						type: "pictorialBar",
						itemStyle: {
							normal: {
								color: "#0F375F",
							},
						},
						symbolRepeat: "fixed",
						symbolMargin: 6,
						symbol: "rect",
						symbolClip: true,
						symbolSize: [barWidth, 2],
						symbolPosition: "start",
						symbolOffset: [0, -1],
						// symbolBoundingData: this.total,
						data: [],
						width: barWidth,
						z: 0,
						zlevel: 1,
					},
				],
			};
		},
		getTitle(opt) {     // 配置标题
			// 未配置标题
			if (!opt || !opt.title) {
				return {
					show: false,
				};
			}
			// 返回标题
			return opt.title;
		},
		resize() {
			let chart = this.$options.chart;
			if (chart) {
				chart.resize();
			}
		},
		/**
		 * 销毁echarts实例释放内存
		 *
		 * @return  {[type]}  [return description]
		 */
		dispose() {
			let chart = this.$options.chart;
			if (chart) {
				chart.dispose(); // 销毁实例
				this.$options.chart = "";
			}
		},
	},
	mounted() {
		this.$options.chart = ECharts.init(this.$refs.chart, "transparent");

		let data = {
			name: "测试",
			list: [
				{
					name: "",
					value: 0,
				},
			],
		};
		this.setData(data);
		// 监听windows窗口的缩放,绑定resize事件
		window.addEventListener("resize", this.resize);
	},
	beforeDestroy() {
		// 销毁resize事件
		window.removeEventListener("resize", this.resize);
		this.dispose();
	},
};
</script>

<style scoped>
.e-chart-root,
.e-chart-container,
.e-chart {
	height: 100%;
	box-sizing: border-box;
}

.e-chart-root.full-screen .e-chart-container {
	position: fixed;
	top: 0;
	left: 0;
	right: 0;
	bottom: 0;
	background-size: 100% 100%;
	z-index: 9999;
}

.e-chart-tools {
	position: absolute;
	top: 16px;
	right: 16px;
	z-index: 9;
}

.e-chart-tools .iconfont {
	margin-left: 8px;
	font-size: 24px;
	cursor: pointer;
	color: #00fefe;
}

.e-chart-tools .iconfont:hover {
	color: #04b1b1;
}

.e-chart-tools .iconfont:active {
	color: #ff0000;
}
</style>
